<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 Final//EN">
<HTML>
<HEAD>
<TITLE>JMo/Pàgina personal d'en Joan Moratinos</TITLE>
</HEAD>


<BODY bgcolor="#FFE081">
<H2>Projectes d'en Joan Moratinos (<a href="mailto:jmo@softcatala.org">jmo@softcatala.org</a>)</H2>

<H4>Corrector de català</H4>
S'ha creat a partir de les entrades del Diccionari de l'Institut d'Estudis
Catalans. Conté totes les formes dels grans dialectes acceptades per l'IEC.

<H4>Versió per a OpenOffice</H4>
Diccionari i llista d'afixos per a MySpell. Funciona amb la versió estàndard de
MySpell per a OpenOffice, però molt més bé si se substitueixen els fitxers
spell641mi.dll i i18n641mi.dll (al directori $OPENOFFICE/program) per uns
d'<a href="../myspell/dlls.rar">adaptats al català</a> (modificat 28/05/03) (aquests fitxers formen part de la versió catalana d'OpenOffice)<br>

<H4>Versió per a ISpell</H4>
Té la mateixa base que el de MySpell, però adaptat a ISpell. Funciona amb
AbiWord. Aquest programa espera un fitxer amb el nom 'catala.hash' al directori
$ABISUITE/dictionary (aquest nom es canviarà segurament a 'catalan.hash' en
versions posteriors d'AbiWord).<br>
Limitacions conegudes del corrector d'AbiWord:
<ul>
<li>La versió que es pot descarregar des de www.abisource.com no reconeix els
guionets com a part de les paraules. Això es resoldrà segurament en pròximes
versions.
<li>Es marquen com a faltes les paraules comunes en majúscules i amb un article
apostrofat. Això sembla una limitació d'ispell (si sabeu com arreglar-ho, <a
href="mailto:jmo@softcatala.org">escriviu-me</a>).
<li>Les propostes no tenen gaire qualitat.
</ul>
<H4>Notes sobre el motor de correcció i els diccionaris</H4>
Darreres modificacions al motor de MySpell:
<UL>
<LI>Ara fa propostes correctes per a paraules com "sel·leccionats" (fins ara només funcionava amb "sel·leccionat")
<LI>Fa propostes correctes per a mots en majúscules i amb apòstrofs
<LI>Tracta adequadament els guionets
<LI>No fa desaparèixer els punts suspensius de les propostes
<LI>Suggereix primer els canvis més probables ("això" per "aixo")
<LI>Fa propostes a més d'una lletra de distància ("col·lega" per "colega")
</UL>
Per fer:
<ul>
<li>Fer propostes intel·ligents (per exemple, proposar "incórrer" per "incurrir" (en totes les formes))
<li>Permetre el canvi dinàmic d'opcions
<li>No convertir els apòstrofs "tipogràfics" a apòstrofs "simples"
</ul>
Darreres modificacions al diccionari:
<ul>
<li>S'han afegit abreviatures, agafades en gran part del <i>Manual de llenguatge administratiu</i>, de Carles Duarte.
<LI>S'han afegit gentilicis i topònims estrangers agafats del <i>Recull de gentilicis</i>, de M.M. Ramon i C. Rigo (Universitat de les Illes Balears)
<LI>S'han corregit errades a les regles que marcavan com incorrectes formes del present d'indicatiu sense desinència.
<li>Versions per als diferents dialectes
<li>Correccions i addicions diverses: "textos", "recursos", "esquiïs"
<li>Primera persona del present d'indicatiu sense desinència: "din", "sop"
<li>Addició de noms propis: tots els municipis dels Països Catalans, noms de persona
</ul>
Per fer:
<ul>
<li>Afegir termes de química (començant pels símbols químics)
<li>Afegir més noms propis: cognoms, noms de productes informàtics
</ul>
<H4>Instruccions d'instal·lació</H4>
Els fitxers .dll van al subdirectori <tt>program</tt>, del directori on heu
instal·lat l'OpenOffice (per exemple <tt>C:\Archivos de
programa\OpenOffice.org1.0\program</tt>). Per canviar aquests fitxers cal
sortir d'OpenOffice i de l'arrencador ràpid (anau a la icona de la barra de
tasques i feis clic a <tt>Exit quickstarter</tt>.<br>

El diccionari i el fitxer d'afixos (que contenen la llista de paraules que 
reconeix el corrector van al subdirectori <tt>user\wordbook</tt>, del directori 
on heu instal·lat l'OpenOffice (per exemple <tt>C:\Archivos de 
programa\OpenOffice.org1.0\user\wordbook</tt>). Podeu canviar-los sense sortir 
d'OpenOffice, però segurament no es reconeixeran els canvis fins que no 
reinicieu (segurament, també l'arrencador ràpid). Heu de posar el valor adequat 
dins el fitxer <tt>dictionary.lst</tt> del mateix subdirectori, o bé trepitjar 
els fitxers que es fan servir actualment. Per exemple, hi ha d'haver una línia a 
<tt>dictionary.lst</tt> amb aquest valor: <br><tt>DICT ca AD catalan</tt> (abans de 
fer qualsevol canvi, feis còpia dels fitxers implicats).<br>


<H4>Descàrregues per al corrector</H4>
<center>
<table border=1 width="80%">
<tr><td colspan=3 align="center"><b>Executables per al corrector d'OpenOffice</b></td></tr>
<tr><td width="65%"><a href="../myspell/dlls.rar">i18n641mi.dll + spell641mi.dll</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">381 K</td></tr>
<tr><td colspan=3 align="center"><b>Font per al corrector d'OpenOffice</b></td></tr>
<tr><td width="65%"><a href="../myspell/myspell_src_cat.rar">Fitxers per a spell641mi.dll</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">23 K</td></tr>
<tr><td colspan=3 align="center"><b>Diccionaris per al corrector d'OpenOffice</b></td></tr>
<tr><td width="65%"><a href="../myspell/catalan.rar">Afixos i llista de paraules per a OO</a></td><td width="20%" align="center">30/01/04</td><td width="15%" align="center">553 K</td></tr>
<tr><td colspan=3 align="center"><b>Fitxers de text per generar hash</b></td></tr>
<tr><td width="65%"><a href="../ispell/catalan.rar">Afixos i llista de paraules per a buildhash</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">522 K</td></tr>
<tr><td colspan=3 align="center"><b>Fitxers hash</b></td></tr>
<tr><td width="65%"><a href="../ispell/catalan2_hash.rar">Fitxer .hash per a ispell</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">1332 K</td></tr>
<tr><td width="65%"><a href="../ispell/catalan_hash.rar">Fitxer .hash per a Abiword</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">1333 K</td></tr>
</table>
</center>
<hr>
<H4>Aplec de diccionaris</H4>
Un sistema per consultar diccionaris des de diversos entorns i per compartir i
intercanviar diccionaris. Aquest programa es troba en una fase encara inicial.
Per això, entre altres problemes, de moment, la instal·lació no està
automatitzada. Podeu seguir aquestes <a href="instr_dic.php">instruccions</a>
per fer la instal·lació.
<H4>Descàrregues per al diccionari</H4>
<center>
<table border=1 width="80%">
<tr><td colspan=3 align="center"><b>Diccionari</b></td></tr>
<tr><td width="65%"><a href="../dic/dic.rar">Motor del diccionari i enllaç amb altres programes</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">367 K</td></tr>
<tr><td width="65%"><a href="../dic/dlls.rar">Biblioteques de Delphi</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">1506 K</td></tr>
<tr><td width="65%"><a href="../dic/diec_dll.rar">Executable per al DIEC</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">64 K</td></tr>
<tr><td width="65%"><a href="../dic/termcat_dll.rar">Executable per a Termcat</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">62 K</td></tr>
<tr><td width="65%"><a href="../dic/gentilicis_dll.rar">Executable per al recull de gentilicis</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">62 K</td></tr>
<tr><td width="65%"><a href="../dic/termcat_dades.rar">Dades del Termcat</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">259 K</td></tr>
<tr><td width="65%"><a href="../dic/gentilicis_dades.rar">Dades del recull de gentilicis</a></td><td width="20%" align="center">28/05/03</td><td width="15%" align="center">20 K</td></tr>
</table>
</center>
</BODY>
</HTML>
